"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toUtf8 = void 0;
const util_buffer_from_1 = require("@smithy/util-buffer-from");
const toUtf8 = (input) => (0, util_buffer_from_1.fromArrayBuffer)(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
exports.toUtf8 = toUtf8;
